Documentation
¶
Overview ¶
This package contains all the functions specific to the server implementation and access.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Generator ¶
type Generator interface {
// Generate a new password and return it.
New() (result string, err error)
}
Password generator
func NewGenerator ¶
Return a generator using the given source.
type Key ¶
type Key interface {
Name() string
Password() string
IsDeleted() bool
Delete()
Encoded() string
Merge(other Key)
SetPassword(pass string)
}
A vault key
type Server ¶
type Server interface {
Open(master string, reply *bool) error
IsOpen(thenClose bool, reply *bool) error
Get(key string, reply *string) error
Set(args SetArgs, reply *string) error
Unset(key string, reply *bool) error
List(filter string, reply *[]string) error
Merge(args MergeArgs, reply *bool) error
Save(force bool, reply *bool) error
Stop(status int, reply *bool) error
Ping(info string, reply *string) error
SetMaster(master string, reply *bool) error
}
The server interface implemented both by the actual (server-side) object and the proxy.
type ServerLocal ¶
A server-side server and extra (non-exported) methods
type Vault ¶
type Vault interface {
Open(master string, config core.Config) error
IsOpen() bool
Close(config core.Config) error
Item(name string) (Key, error)
List(filter string) ([]string, error)
Merge(other Vault) error
Save(force bool, config core.Config) error
SetRandom(name string, recipe string) error
SetPass(name string, pass string) error
Unset(name string) error
SetMaster(master string) error
}
The vault interface.
Click to show internal directories.
Click to hide internal directories.